3 ms·
if you are for perfomance don't use reduce, use loop and time get reduced from 0.38 seconds to 0.049 seconds. (time (loop for x across *nums* sum x)) Eval
by betterorbutter 15y ago
if you are for perfomance don't use reduce, use loop and time get reduced from 0.38 seconds to 0.049 seconds.
(time (loop for x across *nums* sum x))
Evaluation took:
0.049 seconds of real time